==> klat4-0.5.2.tar.bz2: klat4-0.5.2/klat.h <==
/*
    Klat - A LaTeX editor for KDE
    
    Copyright (C) 2002-2004  Jori Liesenborgs (jori@lumumba.luc.ac.be)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef KLAT_H

#define KLAT_H

#include "klatexecconfig.h"
#include <kparts/mainwindow.h>
#include <kxmlguiwindow.h>
//#include <kparts/factory.h>
#include <kxmlguifactory.h>
#include <Qt/qdockwidget.h>

#define VERSION "0.5.2"

class KlatEditTab;
class KlatToolTab;
class KlatOutputTab;
class KMenu;
class KConfig;
class KRecentFilesAction;
class KUrl;
class KAction;
namespace KTextEditor {class View;}

class Klat : public KParts::MainWindow
//class Klat : public KXmlGuiWindow
{
	Q_OBJECT
public:
	Klat();
	~Klat();
	void openCommandLineFile(const QString &fname);
public slots:
	void slotCursorPositionChanged(int line,int col);
	void slotLaTeXCodeChanged(const QString &s);
	void slotLaTeXCodeClear();
	void slotFileReferenced(const KUrl &url);
private slots:
//	void showAboutApplication();
	void slotExecuteSettings();
//	void slotExecMenuItemClicked(int);
	void slotExecMenuItemClicked(QAction*);
	void slotDummy();
	void slotViewToggleTools();
	void slotViewToggleOutput();
	void slotViewCloseTools(bool);
	void slotViewCloseOutput(bool);
	void slotUpdateViewMenu();
	void slotNewDocument(KTextEditor::View*);
private:
	void createWindows();
	void createMenuBarAndToolbarAndStatusBar();
	void buildExecMenu();
	bool queryClose();

	KlatEditTab *edittab;
	KlatToolTab *tooltab;
	KlatOutputTab *outputtab;
	QDockWidget *toolDock,*outputDock;

	KlatExecConfig execConfig;
	KMenu *execMenu;

	KConfig *config;
	KRecentFilesAction *recentFiles;
	KAction *viewToolsAction,*viewOutputAction;
};

#endif // KLAT_H

==> klat4-0.6.1.tar.bz2: klat4-0.6.1/klat.h <==
/*
    Klat4 - A LaTeX editor for KDE4

    Copyright (C) 2008  Anna A. Ladilova (ladilova@algebraic.ru)
    Copyright (C) 2002-2004  Jori Liesenborgs (jori@lumumba.luc.ac.be)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef KLAT_H

#define KLAT_H

#include "klatexecconfig.h"

#include <KParts/MainWindow>

#define VERSION "0.6.0"

class KlatEditTab;
class KlatToolTab;
class KlatOutputTab;
class KMenu;
class KConfig;
class KRecentFilesAction;
class KUrl;
class KAction;
namespace KTextEditor {class View;}
class QDockWidget;

class Klat : public KParts::MainWindow
{
	Q_OBJECT
public:
	Klat();
	~Klat();
	void openCommandLineFile(const QString &fname);
	void createFirstDocument();
public slots:
	void slotCursorPositionChanged(int line,int col);
	void slotLaTeXCodeChanged(const QString &s);
	void slotLaTeXCodeClear();
	void slotFileReferenced(const KUrl &url);
private slots:
	void slotExecuteSettings();
	void slotExecMenuItemClicked(QAction*);
	void slotDummy();
	void slotViewToggleTools();
	void slotViewToggleOutput();
	void slotViewCloseTools(bool);
	void slotViewCloseOutput(bool);
	void slotUpdateViewMenu();
	void slotAddActions(KTextEditor::View*);
private:
	void createWindows();
	void createMenuBarAndToolbarAndStatusBar();
	void buildExecMenu();
	bool queryClose();

	KlatEditTab *edittab;
	KlatToolTab *tooltab;
	KlatOutputTab *outputtab;
	QDockWidget *toolDock,*outputDock;

	KlatExecConfig execConfig;
	KMenu *execMenu;

	KConfig *config;
	KRecentFilesAction *recentFiles;
	KAction *viewToolsAction,*viewOutputAction;
};

#endif // KLAT_H
